# Exchange Electricity Price Indicator

Display the current and upcoming Nord Pool electricity prices in Finland, on an hourly basis, directly in your Gnome Shell top bar.

## Table of Contents

- [Exchange Electricity Price Indicator](#exchange-electricity-price-indicator)
   * [Key Features](#key-features)
   * [Screenshots](#screenshots)
   * [Installation](#installation)
      + [Prerequisites](#prerequisites)
      + [Installation Methods](#installation-methods)
         - [Installation via Git (Recommended)](#installation-via-git-recommended)
         - [Manual installation](#manual-installation)
   * [Running](#running)
   * [Development](#development)
      + [Prerequisites](#prerequisites-1)
      + [Linting and formatting](#linting-and-formatting)
      + [Translations](#translations)
      + [Build extension package](#build-extension-package)
   * [Documentation](#documentation)
   * [Contributing](#contributing)
      + [Issues](#issues)
      + [Code](#code)
   * [Notes](#notes)
   * [License](#license)

## Key Features

- ⚡ Displays the current electricity price in the panel, with an icon indicating high price.
- 💸 Shows the most expensive price rate and period of the day.
- 🕓 Highlights the most affordable hours.
- 💡 Menu provides detailed information, including prices for tomorrow.
- 🌐 Data retrieved from the [Porssisahko.net](https://porssisahko.net/api) API.

## Screenshots

<details>
  <summary><b>Show</b></summary>

  <br/>

_Exchange Electricity Price Indicator in top bar_  
![](resources/eepi-example-screenshot.png)

_Exchange Electricity Price Indicator in Finnish displaying information for today_  
![](resources/eepi-menu-finnish-screenshot.png)

_Exchange Electricity Price Indicator in English displaying information for tomorrow_  
![](resources/eepi-menu-english-screenshot.png)

</details>

## Installation

### Prerequisites

- Linux distribution
- GNOME desktop environment, version 45 or newer

### Installation Methods

#### Installation via Git (Recommended)

Use git to clone the repo:

```bash
git clone https://codeberg.org/artnay/exchange-electricity-price-indicator.git ~/.local/share/gnome-shell/extensions/exchange-electricity-price-indicator@artnay.codeberg.org
```

#### Manual installation

1. Download the extension.
2. Copy the extension folder to one of the following locations:
   - System-wide installation: `/usr/share/gnome-shell/extensions/` (Requires root privileges)
   - User installation: `~/.local/share/gnome-shell/extensions/`

## Running

Enable the extension by running:

```bash
gnome-extensions enable exchange-electricity-price-indicator@artnay.codeberg.org
```

Disable the extension by running:

```bash
gnome-extensions disable exchange-electricity-price-indicator@artnay.codeberg.org
```

## Development

This project uses ESLint with [Gnome's linting rules](https://gitlab.gnome.org/GNOME/gnome-shell-extensions/-/tree/main/lint) and Prettier for formatting.
Husky takes care of git commit hooks. Make targets help with the most common tasks.

### Prerequisites

- GNU gettext-tools >= 0.22.5
- GNU Make >= 4.4.1
- Node.js >= v22.11.0
- npm >= 10.9.0
- pre-commit >= 3.8.0

### Linting and formatting

Install dependencies

```bash
make dev-install
```

Check linting issues:

```bash
make lint
```

Fix linting issues:

```bash
make lint-fix
```

Check formatting issues:

```bash
make check-format
```

Format the code:

```bash
make format
```

### Translations

Generate pot file after string changes in code:

```bash
make pot
```

Include string changes to existing po files:

```bash
make update-po
```

### Build extension package

Build extension as a zip file with required files included:

```bash
make package
```

## Documentation

- [GJS Guide](https://gjs.guide/extensions/) (Gnome Shell extension development documentation)
- [Nordpool.info](https://fi.nordpool.info/en) (Information about the pan-European power exchange)
- [Porssisahko.net API](https://porssisahko.net/api) (Data source for this extension)

## Contributing

### Issues

Report issues to Codeberg [issue tracking system](https://codeberg.org/artnay/exchange-electricity-price-indicator/issues).

### Code

I am open especially to contributions that implement support for other Nord Pool regions using alternative data sources. You can either create a pull request or fork the repository to make changes for your specific needs.

1. Fork the repository
2. Create a feature branch
3. Commit your changes
4. Push to the branch
5. Open a Merge Request

## Notes

Since [Nord Pool](https://www.nordpoolgroup.com/en/trading/api/) does not offer an API without authentication, I use [Porssisahko.net](https://porssisahko.net/api) as a data source.
Unfortunately they do not offer price information for all the countries and regions that are covered by Nord Pool, and therefore only Finnish market is supported by this extension.
Nevertheless, I am thankful for [Porssisahko.net](https://porssisahko.net/) for that they provide an API without authentication.

## License

This project is licensed under GPL-3.0-or-later - see the [LICENSE](LICENSE) file for details.
